[![Build Status](https://travis-ci.org/scruffystuffs/clac.svg?branch=master)](https://travis-ci.org/scruffystuffs/clac)
[![codecov](https://codecov.io/gh/scruffystuffs/clac/branch/master/graph/badge.svg)](https://codecov.io/gh/scruffystuffs/clac)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/clac/badge/?version=latest)](https://clac.readthedocs.io/en/latest/?badge=latest)


# CLAC

CLAC Layerizes Application Configuration

## Status

Currently being refactored for use in the [pedestal](https://github.com/scruffystuffs/pedestal) framework 
